==> CtrlGroupCast_v0.01.zip: Interface/AddOns/CtrlGroupCast/localization.lua <==
-- Version : English - sarf
-- Translation by : None

BINDING_HEADER_CTRLGROUPCASTHEADER		= "Ctrl Group Cast";
BINDING_NAME_CTRLGROUPCAST				= "Ctrl Group Cast Toggle";

BINDING_NAME_CTRLGROUPCAST_TARGET_1		= "Ctrl Group Cast-target the first party member";
BINDING_NAME_CTRLGROUPCAST_TARGET_2		= "Ctrl Group Cast-target the second party member";
BINDING_NAME_CTRLGROUPCAST_TARGET_3		= "Ctrl Group Cast-target the third party member";
BINDING_NAME_CTRLGROUPCAST_TARGET_4		= "Ctrl Group Cast-target the fourth party member";
BINDING_NAME_CTRLGROUPCAST_TARGET_NEXT	= "Ctrl Group Cast-target the next party member";
BINDING_NAME_CTRLGROUPCAST_TARGET_PREV	= "Ctrl Group Cast-target the previous party member";



CTRLGROUPCAST_CONFIG_HEADER				= "Ctrl Group Cast";
CTRLGROUPCAST_CONFIG_HEADER_INFO		= "Contains settings for the Ctrl Group Cast,\nan AddOn which allows you to cast spells/use abilities on your team members quickly and easily.";

CTRLGROUPCAST_ENABLED					= "Enable Ctrl Group Cast";
CTRLGROUPCAST_ENABLED_INFO				= "Enables Ctrl Group Cast,\nwhich means that holding Ctrl and using an action\nwill result in you trying to use it on the current Ctrl-target.\nThe current Ctrl-target is indicated by a fancy icon,\nand is changed by using the bindings provided.";

CTRLGROUPCAST_CHAT_ENABLED				= "Ctrl Group Cast enabled.";
CTRLGROUPCAST_CHAT_DISABLED				= "Ctrl Group Cast disabled.";

CTRLGROUPCAST_CHAT_COMMAND_ENABLE_INFO	= "Enables/disables Ctrl Group Cast.";

CTRLGROUPCAST_CHAT_TARGET_CHANGED		= "Ctrl Group Cast-target changed to target party member %s.";
CTRLGROUPCAST_CHAT_TARGET_INVALID		= "Ctrl Group Cast-target not changed; party member %s was invalid.";

==> CtrlGroupCast_v0.06.zip: Interface/AddOns/CtrlGroupCast/localization.lua <==
-- Version : English - sarf
-- Translation by : None

BINDING_HEADER_CTRLGROUPCASTHEADER		= "Ctrl Group Cast";
BINDING_NAME_CTRLGROUPCAST				= "Ctrl Group Cast Toggle";

BINDING_NAME_CTRLGROUPCAST_TARGET_1		= "Ctrl Group Cast-target the first party member";
BINDING_NAME_CTRLGROUPCAST_TARGET_2		= "Ctrl Group Cast-target the second party member";
BINDING_NAME_CTRLGROUPCAST_TARGET_3		= "Ctrl Group Cast-target the third party member";
BINDING_NAME_CTRLGROUPCAST_TARGET_4		= "Ctrl Group Cast-target the fourth party member";
BINDING_NAME_CTRLGROUPCAST_TARGET_NEXT	= "Ctrl Group Cast-target the next party member";
BINDING_NAME_CTRLGROUPCAST_TARGET_PREV	= "Ctrl Group Cast-target the previous party member";



CTRLGROUPCAST_CONFIG_HEADER				= "Ctrl Group Cast";
CTRLGROUPCAST_CONFIG_HEADER_INFO		= "Contains settings for the Ctrl Group Cast,\nan AddOn which allows you to cast spells/use abilities on your team members quickly and easily.";

CTRLGROUPCAST_ENABLED					= "Enable Ctrl Group Cast";
CTRLGROUPCAST_ENABLED_INFO				= "Enables Ctrl Group Cast,\nwhich means that holding Ctrl and using an action\nwill result in you trying to use it on the current Ctrl-target.\nThe current Ctrl-target is indicated by a fancy icon,\nand is changed by using the bindings provided.";

CTRLGROUPCAST_CHAT_ENABLED				= "Ctrl Group Cast enabled.";
CTRLGROUPCAST_CHAT_DISABLED				= "Ctrl Group Cast disabled.";

CTRLGROUPCAST_CHAT_COMMAND_ENABLE_INFO	= "Enables/disables Ctrl Group Cast.";

CTRLGROUPCAST_CHAT_TARGET_CHANGED		= "CGC: target changed to target party member %s.";
CTRLGROUPCAST_CHAT_TARGET_INVALID		= "CGC: target not changed; party member '%s' was invalid (current group size was '%s').";
CTRLGROUPCAST_CHAT_ONLY_IN_GROUPS		= "CGC: ControlGroupCast can only be used in groups, and CGC does not recognize that you are in one.";
